Package: msqc1
Title: Sigma mix MSQC1 data
Version: 1.41.0
Authors@R: c(person("Tobias", "Kockmann",
        role = c("aut"), comment = c(ORCID = "0000-0002-1847-885X")),
    person("Christian", "Trachsel",
        role = c("aut")),
    person("Christian", "Panse",
        email = "cp@fgcz.ethz.ch",
        role = c("aut", "cre"),
        comment = c(ORCID = "0000-0003-1975-3064")))
Depends: R (>= 3.6), lattice, stats, utils
Suggests: BiocStyle, knitr, rmarkdown, testthat, specL (>= 1.2)
Description: contains eight technical replicate data
        set and a three replicate dilution series of the MS Qual/Quant
        Quality Control Mix standard sample (Sigma-Aldrich, Buchs, Switzerland)
        measured on five different mass spectrometer platforms at the
        Functional Genomics Center Zurich.
License: GPL
LazyData: true
VignetteBuilder: knitr
NeedsCompilation: no
biocViews: ExperimentData, MassSpectrometryData, ReproducibleResearch
URL: https://panoramaweb.org/labkey/MSQC1.url,
        http://fgcz-bfabric.uzh.ch/bfabric/project.html?projectId=1959
git_url: https://git.bioconductor.org/packages/msqc1
git_branch: devel
git_last_commit: 57ada5f
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-30
Packaged: 2026-04-30 15:49:49 UTC; biocbuild
Author: Tobias Kockmann [aut] (ORCID: <https://orcid.org/0000-0002-1847-885X>),
  Christian Trachsel [aut],
  Christian Panse [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-1975-3064>)
Maintainer: Christian Panse <cp@fgcz.ethz.ch>
